@@ -52,11 +52,11 @@ subroutine Dcl_2D_cont_shade( outname,  &
                     ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
   integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
                     ! mono=.true. ΤȤꤷʤȥ顼֤.
-  character(1), intent(in), optional :: trigleg  ! infinity ˻ѷɽ
-                    ! ͤ tone_bar  trigle Ʊ.
+  character(1), intent(in), optional :: trigleg  ! ȡСλѷץ.
+                ! ץͤ, tone_bar 롼 trigle Ʊ.
   integer :: i, j, k  ! ź
   integer :: nx, ny, s_num, c_num
-  real :: vx_min, vx_max, vy_min, vy_max, vy_tonemin, vy_tonemax
+  real :: vx_min, vx_max, vy_min, vy_max
   real :: undef, RMISS
   logical :: monoto
 
@@ -140,7 +140,7 @@ subroutine Dcl_2D_cont_shade( outname,  &
   call DclSetViewPort( vx_min, vx_max, vy_min, vy_max )
   call DclSetTransFunction
 
-  if(monoto==.true.)then
+  if(monoto.eqv..true.)then
      call DclSetParm('ENABLE_SOFTFILL',.true.)
      call DclClearShadeLevel
      call DclSetShadeLevel( mono_val, mono_lev )
@@ -160,7 +160,7 @@ subroutine Dcl_2D_cont_shade( outname,  &
      end if
   end if
 
-  if(monoto==.true.)then
+  if(monoto.eqv..true.)then
      call DclShadeContour( shade )
   else
      call DclShadeContourEx( shade )
@@ -184,22 +184,11 @@ subroutine Dcl_2D_cont_shade( outname,  &
   end if
 
   if(present(trigleg))then
-     select case(trigleg)
-     case ('a')
-        vy_tonemin=vy_min+0.025  ! ѷΥǥեȤĹդĹȰ
-        vy_tonemax=vy_max-0.025
-     case ('u')
-        vy_tonemin=vy_min+0.025
-     case ('d')
-        vy_tonemax=vy_max-0.025
-     end select
-
-     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,  &
-  &                 vy_tonemin, vy_tonemax, form_types, mono_log=monoto,  &
-  &                 trigle=trigleg )
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vy_min, vy_max, form_types, mono_log=monoto, trigle=trigleg )
   else
-     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,  &
-  &                 vy_min, vy_max, form_types, mono_log=monoto )
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vy_min, vy_max, form_types, mono_log=monoto )
   end if
 
 end subroutine
@@ -211,7 +200,7 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
   &  shade_min, shade_max, x_title, y_title, form_typec,  &
   &  form_types, viewx_min, viewx_max, viewy_min,  &
   &  viewy_max, color_num, cont_num, nongrid,  &
-  &  xg, yg, mono, mono_val, mono_lev )
+  &  xg, yg, mono, mono_val, mono_lev, trigleg, mlitv )
   ! 2  2 ѿȥ顼ɤ褹.
   !  map_pro Ͽֹ, Ͽƥ⡼ɤڤؤ.
   ! , xg, yg ץϿƤδط, ǽƤʤ.
@@ -257,6 +246,9 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
                     ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
   integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
                     ! mono=.true. ΤȤꤷʤȥ顼֤.
+  character(1), intent(in), optional :: trigleg  ! ȡСλѷץ.
+                ! ץͤ, tone_bar 롼 trigle Ʊ.
+  real, intent(in), optional :: mlitv  ! ᥸㡼饤, ɽֳ [degree]. ǥեȤ 1 degree.
   real, parameter :: pi=3.14159265
   real, parameter :: radius=6.38e6
   integer :: i, j, k  ! ź
@@ -265,7 +257,7 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
   real :: vx_min, vx_max, vy_min, vy_max
   real :: undef, RMISS
   real :: map_lat_min, map_lat_max, map_lon_min, map_lon_max
-  real :: mlat2dis_min, mlat2dis_max
+  real :: mlat2dis_min, mlat2dis_max, mditv
   logical :: monoto
 
   nx=size(x)
@@ -305,6 +297,12 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
      vy_max=0.8
   end if
 
+  if(present(mlitv))then
+     mditv=mlitv
+  else
+     mditv=1.0
+  end if
+
 !-- ϿȼΥץ ---
 !-- MapFit 롼Ѥ, Ͽޤ vp ŪѹΤ,
 !-- νԤ.
@@ -374,7 +372,8 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
   call DclNewFrame
   call DclSetParm( 'MAP:LGRIDMN', .false. )
   call DclSetParm( 'MAP:INDEXMJ', 1 )
-  call DclSetParm( 'MAP:dgridmj', 1. )
+!  call DclSetParm( 'MAP:INDEXOUT', 51 )  ! ο, ɤ뤫Ϻƹ
+  call DclSetParm( 'MAP:dgridmj', mditv )
 
   call DclSetWindow( x(1), x(nx), y(1), y(ny) )
   call DclSetViewPort( vx_min, vx_max, vy_min, vy_max )
@@ -382,7 +381,7 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
   call DclFitMapParm
   call DclSetTransFunction
 
-  if(monoto==.true.)then
+  if(monoto.eqv..true.)then
      call DclSetParm('ENABLE_SOFTFILL',.true.)
      call DclClearShadeLevel
      call DclSetShadeLevel( mono_val, mono_lev )
@@ -404,7 +403,7 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
      end if
   end if
 
-  if(monoto==.true.)then
+  if(monoto.eqv..true.)then
      call DclShadeContour( shade )
   else
      call DclShadeContourEx( shade )
@@ -412,8 +411,9 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
 
   CALL UZLSET( 'LABELYL', .TRUE. )
   CALL UZLSET( 'LABELYR', .FALSE. )
-  call DclDrawAxis( 'bt', 1.0, 0.5 )
-  call DclDrawAxis( 'rl', 1.0, 0.5 )
+
+  call DclDrawAxis( 'bt', mditv, 0.5*mditv )
+  call DclDrawAxis( 'rl', mditv, 0.5*mditv )
 !  call DclDrawScaledAxis
   call DclDrawTitle( 'b', x_title, 0.0 )
   call DclDrawTitle( 'l', y_title, 0.0 )
@@ -425,7 +425,293 @@ subroutine Dcl_2D_cont_shade_MapPro( map_pro, outname,  &
   call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/c_num )
   call DclDrawContour( contour )
 
-  call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types, mono_log=monoto )
+  if(present(trigleg))then
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vy_min, vy_max, form_types, mono_log=monoto, trigle=trigleg )
+  else
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vy_min, vy_max, form_types, mono_log=monoto )
+  end if
+
+end subroutine
+
+!---------------------------------------------------------
+
+subroutine Dcl_2D_cont_shade_terrain( outname,  &
+  &  x, y, grid_point, contour, shade, cont_min, cont_max,  &
+  &  shade_min, shade_max, x_title, y_title,  &
+  &  form_typec, form_types, viewx_min, viewx_max,  &
+  &  viewy_min, viewy_max, color_num, cont_num, nongrid,  &
+  &  xg, yg, mono, mono_val, mono_lev, trigleg, trn_paint, trn_col, layer_line )
+  ! 2  2 ѿȥ顼ɤ褹.
+  ! terrain following 
+  use dcl
+  implicit none
+  character(*), intent(in) :: outname  ! դΥȥ
+  real, intent(in) :: x(:)  ! x γʻɸ
+  real, intent(in) :: y(:)  ! y γʻɸ
+  real, intent(in) :: grid_point(size(x),size(y))  ! terrain following ɸ
+  real, intent(inout) :: contour(size(x),size(y))  ! 
+  real, intent(inout) :: shade(size(x),size(y))  ! 顼ɤ
+  real, intent(in) :: cont_min  ! Ǿ
+  real, intent(in) :: cont_max  ! 
+  real, intent(in) :: shade_min  ! ɤǾ
+  real, intent(in) :: shade_max  ! ɤ
+  character(*), intent(in) :: x_title  ! x Υȥ
+  character(*), intent(in) :: y_title  ! y Υȥ
+  character(6), intent(in) :: form_typec  ! contour ѤΥեޥå
+  character(6), intent(in) :: form_types  ! shade ѤΥեޥå
+  real, intent(in), optional :: viewx_min  ! ӥ塼ݡȤ x κǾ
+  real, intent(in), optional :: viewx_max  ! ӥ塼ݡȤ x κ
+  real, intent(in), optional :: viewy_min  ! ӥ塼ݡȤ y κǾ
+  real, intent(in), optional :: viewy_max  ! ӥ塼ݡȤ y κ
+  integer, intent(in), optional :: color_num  ! 顼ο
+  integer, intent(in), optional :: cont_num  ! ο
+  character(2), intent(in), optional :: nongrid  ! ֳֳʻҤˤ뤫.
+                                        ! nongrid = 'ox' Ƚ.
+                                        ! 1 ʸܤ, 2 ʸܤļ.
+                                        ! o = ֳ, x = ֳ.
+                                        ! ǥեȤǤ 'xx'.
+  real, intent(in), optional :: xg(:,:)  ! x 륰åκɸ
+  real, intent(in), optional :: yg(:,:)  ! y 륰åκɸ
+                    ! Ǥΰ֥ǡ, ʣ,
+                    ! Ǥ 2 İʾˤ.
+                    ! ǡľǤϤʤ, åɤ
+                    ! Ȥǽ.
+                    ! 3 ܤ, xg(:,1)  yg(:,1)  1 ܤ
+                    ! ɽ褦˻ꤹ뤳.
+  logical, intent(in), optional :: mono  ! ΥȡγĴˤ [.true.]
+                                         ! ǥեȤ .false.
+  real, intent(in), optional :: mono_val(:)  ! Ĵζ.
+                    ! mono=.true. ΤȤɬꤷʤȥ顼֤.
+                    ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
+  integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
+                    ! mono=.true. ΤȤꤷʤȥ顼֤.
+  character(1), intent(in), optional :: trigleg  ! ȡСλѷץ.
+                ! ץͤ, tone_bar 롼 trigle Ʊ.
+  logical, intent(in), optional :: trn_paint  ! Ϸ˿ɤ뤫. [def:.false.]
+  integer, intent(in), optional :: trn_col  ! Ϸɤ뿧Υ顼ֹ
+  logical, intent(in), optional :: layer_line  ! ؤγʻɽ. [def:.false.]
+  integer :: i, j, k  ! ź
+  integer :: nx, ny, s_num, c_num
+  real :: vx_min, vx_max, vy_min, vy_max
+  real :: undef, RMISS, interc
+  logical :: monoto
+  real :: cx(size(x),size(y)), cy(size(x),size(y))
+  real :: trn(size(x)+2), trn_x(size(x)+2)
+  real :: cxmax, cxmin, cymax, cymin
+  character(10) :: val_c
+  integer :: maxcy, maxcx, trn_color
+
+  nx=size(x)
+  ny=size(y)
+
+!-- c ɸϤؤѴ
+  do j=1,ny
+     do i=1,nx
+        cx(i,j)=x(i)
+        cy(i,j)=grid_point(i,j)
+     end do
+  end do
+
+!-- c ɸ϶ͤη׻
+
+  cxmin=x(1)
+  cxmax=x(nx)
+  cymin=cy(1,1)
+  cymax=cy(1,ny)
+  do i=2,nx
+     if(cymin>cy(i,1))then
+        cymin=cy(i,1)
+     end if
+     if(cymax<cy(i,ny))then
+        cymax=cy(i,ny)
+     end if
+  end do
+
+!-- optional ν ---
+  if(present(viewx_min))then
+     vx_min=viewx_min
+  else
+     vx_min=0.2
+  end if
+
+  if(present(viewx_max))then
+     vx_max=viewx_max
+  else
+     vx_max=0.8
+  end if
+
+  if(present(viewy_min))then
+     vy_min=viewy_min
+  else
+     vy_min=0.2
+  end if
+
+  if(present(viewy_max))then
+     vy_max=viewy_max
+  else
+     vy_max=0.8
+  end if
+
+  if(present(color_num))then
+     s_num=color_num
+  else
+     s_num=56
+  end if
+
+  if(present(cont_num))then
+     c_num=cont_num
+  else
+     c_num=10
+  end if
+
+  if(present(mono))then
+     if(present(mono_val).and.present(mono_lev))then
+        if(size(mono_val)-1==size(mono_lev))then
+           monoto=mono
+        else
+           write(*,*) "*** ERROR ***"
+           write(*,*) "[array number] : mono_val = mono_lev + 1"
+           write(*,*) "STOP"
+           stop
+        end if
+     else
+        write(*,*) "*** ERROR ***"
+        write(*,*) "When option MONO is true, MONO_VAL and MONO_LEV must be specified."
+        write(*,*) "STOP"
+        stop
+     end if
+  else
+     monoto=.false.
+  end if
+
+!-- ޤ ---
+
+!-- contour  axis Τ,  contour interval ɽʤ
+!-- 褦ˤ롼. contour interval .
+  call udlset('LMSG',.false.)
+
+  call undef_CReSS2Dcl( nx, ny, 1, contour)
+  call undef_CReSS2Dcl( nx, ny, 1, shade)
+
+  call UWSGXZ(.FALSE.)
+  call UWSGYZ(.FALSE.)
+
+  call DclNewFrame
+  call DclSetWindow( x(1), x(nx), y(1), y(ny) )
+
+  if(present(xg))then
+     do i=1,size(xg,2)
+        call DclScalingPoint( xg(:,i), yg(:,i) )
+     end do
+  end if
+
+  call DclSetViewPort( vx_min, vx_max, vy_min, vy_max )
+  call DclSetTransNumber(51)
+  call g2sctr(nx, ny, x, y, cx, cy )
+  call DclSetTransFunction
+
+  if(monoto.eqv..true.)then
+     call DclSetParm('ENABLE_SOFTFILL',.true.)
+     call DclClearShadeLevel
+     call DclSetShadeLevel( mono_val, mono_lev )
+  else
+     call DclSetParm('ENABLE_SOFTFILL',.false.)
+!     call DclSetParm('ENABLE_SOFTFILL',.true.)
+!     call DclClearShadeLevel
+!     call DclSetShadeLevel( shade_min, shade_max,   &
+! &                          (shade_max-shade_min)/s_num )
+  end if
+
+  call uelset('ltone',.true.)
+
+  if(present(nongrid))then
+     if(nongrid(1:1)=='o')then
+        call DclSetXGrid( x )
+     end if
+     if(nongrid(2:2)=='o')then
+        call DclSetYgrid( y )
+     end if
+  end if
+
+!  if(monoto.eqv..true.)then
+!     call DclShadeContour( shade )
+!  else
+     call DclShadeContour( shade )
+!  end if
+
+  call DclSetContourLabelFormat(form_typec)
+  call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/c_num )
+  call DclDrawContour( contour )
+
+  call g2qctm( cxmin, cxmax, cymin, cymax )
+  call DclSetWindow( cxmin, cxmax, cymin, cymax )
+  call DclSetTransNumber(1)
+  call DclSetTransFunction
+
+  CALL UZLSET( 'LABELYL', .TRUE. )
+  CALL UZLSET( 'LABELYR', .FALSE. )
+  call DclDrawScaledAxis
+  call DclDrawTitle( 'b', x_title, 0.0 )
+  call DclDrawTitle( 'l', y_title, 0.0 )
+  call DclDrawTitle( 't', outname, 0.0, 2 )
+
+!-- Ϸΰ˿ɤ
+  if(present(trn_paint))then
+     if(trn_paint.eqv..true.)then
+        if(present(trn_col))then
+           trn_color=trn_col
+        else
+           trn_color=1999
+        end if
+        do i=1,nx
+           trn(i)=grid_point(i,1)
+           trn_x(i)=x(i)
+!        if(bot(i)==trn(i))then
+!           call DclShadeRegion( )
+!        end if
+        end do
+        trn(nx+1)=cymin
+        trn(nx+2)=cymin
+        trn_x(nx+1)=x(nx)
+        trn_x(nx+2)=x(1)
+
+        call DclShadeRegion( trn_x(1:nx+2), trn(1:nx+2), trn_color)
+     end if
+  end if
+
+!  call DclSetContourLabelFormat(form_typec)
+!  call DclSetContourLevel( cont_min, cont_max, (cont_max-cont_min)/c_num )
+!  call DclDrawContour( contour )
+
+  interc=DclGetContourInterval(1)
+  write(*,*) interc
+  write(val_c,'(E10.3)') interc
+
+  call DclDrawTitle('b','_CONTOUR INTERVAL ='//val_c//'"',0.0,1)
+
+  if(present(xg))then
+     do i=1,size(xg,2)
+        call DclDrawLine( xg(:,i), yg(:,i) )
+     end do
+  end if
+
+  if(present(layer_line))then
+     if(layer_line.eqv..true.)then
+        do i=1,ny
+           call DclDrawLine( x, grid_point(:,i) )
+        end do
+     end if
+  end if
+
+  if(present(trigleg))then
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vy_min, vy_max, form_types, mono_log=monoto, trigle=trigleg )
+  else
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vy_min, vy_max, form_types, mono_log=monoto )
+  end if
 
 end subroutine
 
@@ -436,7 +722,7 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
   &  shade_min, shade_max, x_title, y_title, date, days,  &
   &  form_typec, form_types, viewx_min, viewx_max,  &
   &  viewy_min, viewy_max, color_num, cont_num, nongrid,  &
-  &  xg, yg, mono, mono_val, mono_lev )
+  &  xg, yg, mono, mono_val, mono_lev, trigleg )
   ! 2  2 ѿȥ顼ɤ褹. calender б
   use dcl
   implicit none
@@ -481,6 +767,8 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
                     ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
   integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
                     ! mono=.true. ΤȤꤷʤȥ顼֤.
+  character(1), intent(in), optional :: trigleg  ! ȡСλѷץ.
+                ! ץͤ, tone_bar 롼 trigle Ʊ.
   integer :: i, j, k  ! ź
   integer :: nx, ny, s_num, c_num
   real :: vx_min, vx_max, vy_min, vy_max
@@ -569,7 +857,7 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
   call DclSetViewPort( vx_min, vx_max, vy_min, vy_max )
   call DclSetTransFunction
 
-  if(monoto==.true.)then
+  if(monoto.eqv..true.)then
      call DclSetParm('ENABLE_SOFTFILL',.true.)
      call DclClearShadeLevel
      call DclSetShadeLevel( mono_val, mono_lev )
@@ -589,7 +877,7 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
      end if
   end if
 
-  if(monoto==.true.)then
+  if(monoto.eqv..true.)then
      call DclShadeContour( shade )
   else
      call DclShadeContourEx( shade )
@@ -612,7 +900,13 @@ subroutine Dcl_2D_cont_shade_calendar( outname,  &
      end do
   end if
 
-  call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types, mono_log=monoto )
+  if(present(trigleg))then
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vy_min, vy_max, form_types, mono_log=monoto, trigle=trigleg )
+  else
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vy_min, vy_max, form_types, mono_log=monoto )
+  end if
 
 end subroutine
 
@@ -623,7 +917,8 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
   &  shade_min, shade_max, x_title, y_title,  &
   &  form_typec, form_types, viewx_min, viewx_max,  &
   &  viewy_min, viewy_max, color_num, cont_num, nongrid,  &
-  &  xg, yg, mono, mono_val, mono_lev )
+  &  xg, yg, mono, mono_val, mono_lev, trigleg, unitv, vfact, unit_fact_sign, &
+  &  unit_fact, unit_title, unit_posi )
   ! 2  3 ѿ, 顼, ٥ȥ褹.
   !  4 ѿƱ褬ǽȤʤ.
   ! Ū˱˥顼СĤΤ, ˥åȥ٥ȥ
@@ -673,14 +968,34 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
                     ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
   integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
                     ! mono=.true. ΤȤꤷʤȥ顼֤.
+  character(1), intent(in), optional :: trigleg  ! ȡСλѷץ.
+                ! ץͤ, tone_bar 롼 trigle Ʊ.
+  logical, intent(in), optional :: unitv  ! ñ̥٥ȥɤ. default = .true.
+  real, intent(in), optional :: vfact(2)  ! x,y Υ󥰥ե
+                    ! ͤꤹ, Ū˷ʤΤ, ٥ȥ뤬ʻҰʾ
+                    ! Ӥǽ. 
+                    ! ꤷʤ, x, y οʿ V ϤΥڥθ
+                    ! , vfact Ȱפ褦ˤ.
+  logical, intent(in), optional :: unit_fact_sign  ! unitv = .true. ΤȤ,
+                    ! .true. = u, v  U ɸϤǤͤ unit_fact Ϳ, 
+                    ! unit_fact Ϥͤñ̥٥ȥñ̤Ȥɽ.
+                    ! unit  V ɸϤͤ u, v 礭 0.1 Ȥɽ.
+  real, intent(in), optional :: unit_fact(2)  ! x,y ñ̥٥ȥ v ɸϤǤĹ
+                                              ! default = (0.1,0.1)
+  character(*), intent(in), optional :: unit_title(2)  ! x,y ñ̥٥ȥΥȥ
+                    ! default = ʤ.
+  real, intent(in), optional :: unit_posi(2)  ! ñ̥٥ȥϤ븶ɸ (V )
+                    ! default = 顼СκüƱ, ޤαü鳫.
+                    ! 顼СϤˤ֤Ĥʤ褦˼ưŪû.
   integer :: i, j, k  ! ź
   integer :: nx, ny, s_num, c_num
   real :: factx, facty
   real, dimension(vnx,vny) :: um, vm  ! ٥ȥְͤ
-  real :: vx_min, vx_max, vy_min, vy_max
+  real :: vx_min, vx_max, vy_min, vy_max, vvx_min, vvx_max, vvy_min, vvy_max
+  real :: unitvp(2), unitvl(2), unit_auto_fact(2)
   real :: undef, RMISS
   intrinsic :: nint
-  logical :: monoto
+  logical :: monoto, unitvs
 
   nx=size(x)
   ny=size(y)
@@ -807,10 +1122,105 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
      end do
   end if
 
+!-- ٥ȥ륹ˤĤƤ
+  if(present(unit_fact_sign))then
+     if(unit_fact_sign.eqv..true.)then
+        if(present(unit_fact))then
+           unit_auto_fact(1)=unit_fact(1)
+           unit_auto_fact(2)=unit_fact(2)
+        else
+           write(*,*) "### ERROR ### : unit_fact_sign is .true. then,"
+           write(*,*) "                unit_fact must configure."
+           write(*,*) "STOP."
+           stop
+        end if
+     else
+        unit_auto_fact(1)=1.0
+        unit_auto_fact(2)=1.0
+     end if
+  else
+     unit_auto_fact(1)=1.0
+     unit_auto_fact(2)=1.0
+  end if
+
+  if(present(vfact))then
+     call DclSetParm( 'VECTOR:LNRMAL', .false. )
+     call DclSetParm( 'VECTOR:XFACT1', vfact(1) )
+     call DclSetParm( 'VECTOR:YFACT1', vfact(2) )
+     unit_auto_fact(1)=unit_auto_fact(1)*vfact(1)
+     unit_auto_fact(2)=unit_auto_fact(2)*vfact(2)
+  else
+     call DclSetParm( 'VECTOR:LNRMAL', .true.)
+     call DclSetParm( 'VECTOR:XFACT1', unitvl(1) )
+     call DclSetParm( 'VECTOR:YFACT1', unitvl(2) )
+     unit_auto_fact(1)=unit_auto_fact(1)*unitvl(1)
+     unit_auto_fact(2)=unit_auto_fact(2)*unitvl(2)
+     unitvl=0.0
+  end if
+
+!-- ˥åȥ٥ȥˤĤƤ
+  if(present(unitv))then
+     unitvs=unitv
+  else
+     unitvs=.true.
+  end if
+
+  if(unitvs.eqv..true.)then
+
+     call DclSetParm( 'VECTOR:LUNIT', unitvs )
+
+     !-- ñ̥٥ȥĹ
+     if(present(unit_fact))then
+        if(present(unit_fact_sign))then
+           if(unit_fact_sign.eqv..true.)then
+              unitvl(:)=unit_auto_fact(:)
+           else
+              unitvl(:)=unit_fact(:)
+           end if
+        else
+           unitvl(:)=unit_fact(:)
+        end if
+     else
+        unitvl=(/0.1, 0.1/)
+     end if
+
+     !-- ñ̥٥ȥν񤭻Ϥΰ
+     if(present(unit_posi))then
+        vvx_min=unit_posi(1)
+        vvy_min=unit_posi(2)
+     else
+        vvx_min=vx_max+0.05
+        vvy_min=vy_min
+     end if
+
+     vvy_max=vvy_min+unitvl(2)+0.05
+
+     call DclSetParm( 'VECTOR:VXUNIT', unitvl(1) )
+     call DclSetParm( 'VECTOR:VYUNIT', unitvl(2) )
+     call DclSetParm( 'VECTOR:VXULOC', vvx_min )
+     call DclSetParm( 'VECTOR:VYULOC', vvy_min )
+
+     !-- ȥ񤯤ɤ
+     if(present(unit_title))then
+        call DclSetUnitVectorTitle( 'X', trim(unit_title(1)) )
+        call DclSetUnitVectorTitle( 'Y', trim(unit_title(2)) )
+        call DclSetParm( 'VECTOR:LUMSG', .false. )
+     else  ! ȥ񤫤ʤʤ, դβ˥󥰥ե
+        call DclSetParm( 'VECTOR:LUMSG', .true. )
+     end if
+
+  else
+     call DclSetParm( 'VECTOR:LUNIT', unitvs )
+     vvx_min=0.0
+     vvx_max=0.0
+     vvy_min=0.0
+     vvy_max=vy_min
+  end if
+
   call DclSetViewPort( vx_min, vx_max, vy_min, vy_max )
   call DclSetTransFunction
 
-  if(monoto==.true.)then
+  if(monoto.eqv..true.)then
      call DclSetParm('ENABLE_SOFTFILL',.true.)
      call DclClearShadeLevel
      call DclSetShadeLevel( mono_val, mono_lev )
@@ -830,7 +1240,7 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
      end if
   end if
 
-  if(monoto==.true.)then
+  if(monoto.eqv..true.)then
      call DclShadeContour( shade )
   else
      call DclShadeContourEx( shade )
@@ -855,7 +1265,13 @@ subroutine Dcl_2D_cont_shade_vec( outname,  &
      end do
   end if
 
-  call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types, mono_log=monoto )
+  if(present(trigleg))then
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vvy_max, vy_max, form_types, mono_log=monoto, trigle=trigleg )
+  else
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vvy_max, vy_max, form_types, mono_log=monoto )
+  end if
 
 end subroutine
 
@@ -866,7 +1282,7 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
   &  shade_min, shade_max, x_title, y_title, date, days,  &
   &  form_typec, form_types, viewx_min, viewx_max,  &
   &  viewy_min, viewy_max, color_num, cont_num, nongrid,  &
-  &  xg, yg, mono, mono_val, mono_lev )
+  &  xg, yg, mono, mono_val, mono_lev, trigleg )
   ! 2  3 ѿ, 顼, ٥ȥ褹.
   !  4 ѿƱ褬ǽȤʤ.
   ! Ū˱˥顼СĤΤ, ˥åȥ٥ȥ
@@ -918,6 +1334,8 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
                     ! ͤ mono_lev + 1 ʬ¸ߤʤФʤʤ.
   integer, intent(in), optional :: mono_lev(:)  ! ȡޥåֹ. dcl  3 
                     ! mono=.true. ΤȤꤷʤȥ顼֤.
+  character(1), intent(in), optional :: trigleg  ! ȡСλѷץ.
+                ! ץͤ, tone_bar 롼 trigle Ʊ.
   integer :: i, j, k  ! ź
   integer :: nx, ny, s_num, c_num
   real :: factx, facty
@@ -1057,7 +1475,7 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
   call DclSetViewPort( vx_min, vx_max, vy_min, vy_max )
   call DclSetTransFunction
 
-  if(monoto==.true.)then
+  if(monoto.eqv..true.)then
      call DclSetParm('ENABLE_SOFTFILL',.true.)
      call DclClearShadeLevel
      call DclSetShadeLevel( mono_val, mono_lev )
@@ -1077,7 +1495,7 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
      end if
   end if
 
-  if(monoto==.true.)then
+  if(monoto.eqv..true.)then
      call DclShadeContour( shade )
   else
      call DclShadeContourEx( shade )
@@ -1102,13 +1520,19 @@ subroutine Dcl_2D_cont_shade_vec_calendar( outname,  &
      end do
   end if
 
-  call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, 0.875, vy_min, vy_max, form_types, mono_log=monoto )
+  if(present(trigleg))then
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vy_min, vy_max, form_types, mono_log=monoto, trigle=trigleg )
+  else
+     call tone_bar( s_num, shade_min, shade_max, vx_max+0.05, vx_max+0.075,   &
+  &               vy_min, vy_max, form_types, mono_log=monoto )
+  end if
 
 end subroutine
 
 !---------------------------------------------------------
 
-subroutine Dcl_PL( judge, outname, lnum, pnum, lstep, pstep,  &
+subroutine Dcl_PL( judge, outname,  &
   &  xline, yline, xpoint, ypoint, x_title, y_title,  &
   &  viewx_min, viewx_max, viewy_min, viewy_max, xmin, xmax, ymin, ymax )
   ! 2 ʿˤʣζ, ݥȤ褹.
@@ -1130,14 +1554,10 @@ subroutine Dcl_PL( judge, outname, lnum, pnum, lstep, pstep,  &
                 ! 'p' = ݥȤΤ, 'l' = 饤Τ, 'a' = ξ.
                 ! 褷ʤǤ, ߡɤ߹ޤɬפ.
   character(*), intent(in) :: outname  ! դΥȥ
-  integer, intent(in) :: lnum  ! ܿ
-  integer, intent(in) :: pnum  ! ݥȤμ
-  integer, intent(in) :: lstep  !  1 ܤ
-  integer, intent(in) :: pstep  ! 1 ΥݥȤθĿ
-  real, intent(in) :: xline(lstep, lnum)  !  x ɸ
-  real, intent(in) :: yline(lstep, lnum)  !  y ɸ
-  real, intent(in) :: xpoint(pstep, pnum)  ! ݥȷ x ɸ
-  real, intent(in) :: ypoint(pstep, pnum)  ! ݥȷ y ɸ
+  real, intent(in) :: xline(:,:)  !  x ɸ
+  real, intent(in) :: yline(size(xline,1),size(xline,2))  !  y ɸ
+  real, intent(in) :: xpoint(:,:)  ! ݥȷ x ɸ
+  real, intent(in) :: ypoint(size(xpoint,1),size(xpoint,2))  ! ݥȷ y ɸ
   character(*), intent(in) :: x_title  ! x Υȥ
   character(*), intent(in) :: y_title  ! y Υȥ
   real, intent(in), optional :: viewx_min  ! ӥ塼ݡȤ x κǾ
@@ -1150,9 +1570,14 @@ subroutine Dcl_PL( judge, outname, lnum, pnum, lstep, pstep,  &
   real, intent(in), optional :: ymax  ! y Υձü
   integer :: i, j, k  ! ź
   integer, parameter :: lim=990  ! 饤󥤥ǥåκ
-  integer :: nnum
+  integer :: nnum, lstep, pstep, lnum, pnum
   real :: vx_min, vx_max, vy_min, vy_max
 
+  lstep=size(xline,1)
+  pstep=size(xpoint,1)
+  lnum=size(xline,2)
+  pnum=size(xpoint,2)
+
 !-- optional ν ---
   if(present(viewx_min))then
      vx_min=viewx_min
@@ -1246,8 +1671,8 @@ end subroutine
 
 !---------------------------------------------------------
 
-subroutine Dcl_PL_vec( outname,  &
-  &  x, y, lnum, pnum, lstep, pstep, xline, yline, xpoint, ypoint,  & 
+subroutine Dcl_PL_vec( judge, outname, x, y,  &
+  &  xline, yline, xpoint, ypoint,  & 
   &  vecx, vecy, vnx, vny, x_title, y_title,  &
   &  viewx_min, viewx_max, viewy_min, viewy_max )
   ! 2 ʿˤƥ٥ȥʣζ, ݥȤ褹.
@@ -1263,19 +1688,19 @@ subroutine Dcl_PL_vec( outname,  &
   ! Ȥưɤ߹ޤФ褤.
   ! ΤȤ, ΰбطϰʲΤȤǤ.
   ! lnum = 3, pnum = 5, lstep = 1000, pstep = 100
+!!!!!!!!!! Ϥޤ٥ȥΥڥȼưĴᵡǽϤʤ.
   use dcl
   implicit none
+  character(1), intent(in) :: judge  ! դμ
+                ! 'p' = ݥȤΤ, 'l' = 饤Τ, 'a' = ξ.
+                ! 褷ʤǤ, ߡɤ߹ޤɬפ.
   character(*), intent(in) :: outname  ! դΥȥ
-  real, intent(in) :: x(:)  ! x γʻɸ
-  real, intent(in) :: y(:)  ! y γʻɸ
-  integer, intent(in) :: lnum  ! ܿ
-  integer, intent(in) :: pnum  ! ݥȤμ
-  integer, intent(in) :: lstep  !  1 ܤ
-  integer, intent(in) :: pstep  ! 1 ΥݥȤθĿ
-  real, intent(in) :: xline(lstep, lnum)  !  x ɸ
-  real, intent(in) :: yline(lstep, lnum)  !  y ɸ
-  real, intent(in) :: xpoint(pstep, pnum)  ! ݥȷ x ɸ
-  real, intent(in) :: ypoint(pstep, pnum)  ! ݥȷ y ɸ
+  real, intent(in) :: x(:)  ! x ɸ, ΰθȥ٥ȥǿ
+  real, intent(in) :: y(:)  ! y ɸ, ΰθȥ٥ȥǿ
+  real, intent(in) :: xline(:,:)  !  x ɸ
+  real, intent(in) :: yline(size(xline,1),size(xline,2))  !  y ɸ
+  real, intent(in) :: xpoint(:,:)  ! ݥȷ x ɸ
+  real, intent(in) :: ypoint(size(xpoint,1),size(xpoint,2))  ! ݥȷ y ɸ
   real, intent(in) :: vecx(size(x),size(y))  ! x Υ٥ȥ
   real, intent(in) :: vecy(size(x),size(y))  ! x Υ٥ȥ
   integer, intent(in) :: vnx  ! x Υ٥ȥʻ (ְ)
@@ -1288,6 +1713,8 @@ subroutine Dcl_PL_vec( outname,  &
   real, intent(in), optional :: viewy_max  ! ӥ塼ݡȤ y κ
   integer :: i, j, k  ! ź
   integer :: nx, ny
+  integer :: nnum, lstep, pstep, lnum, pnum
+  integer, parameter :: lim=990  ! 饤󥤥ǥåκ
   real :: factx, facty
   real, dimension(vnx,vny) :: um, vm  ! ٥ȥְͤ
   real :: vx_min, vx_max, vy_min, vy_max
@@ -1296,6 +1723,11 @@ subroutine Dcl_PL_vec( outname,  &
   nx=size(x)
   ny=size(y)
 
+  lstep=size(xline,1)
+  pstep=size(xpoint,1)
+  lnum=size(xline,2)
+  pnum=size(xpoint,2)
+
 !-- optional ν ---
   if(present(viewx_min))then
      vx_min=viewx_min
@@ -1379,20 +1811,25 @@ subroutine Dcl_PL_vec( outname,  &
 !-- ݥȤȶ ---
 !-- num ˱ do 롼פǲ󤹤Τ, num Ǥդ OK.
 !-- num = 1 ξϹǸ
-  if(pnum==1)then
-     call DclDrawMarker( xpoint(:,1), yline(:,1) )
-  else
-     do i=1,pnum
-        call DclDrawMarker( xpoint(:,j), yline(:,j), type=j )
-     end do
+  if(judge=='p'.or.judge=='a')then
+     if(pnum==1)then
+        call DclDrawMarker( xpoint(:,1), ypoint(:,1) )
+     else
+        do i=1,pnum
+           call DclDrawMarker( xpoint(:,j), ypoint(:,j), type=j )
+        end do
+     end if
   end if
 
-  if(lnum==1)then
-     call DclDrawLine( xline(:,1), yline(:,1) )
-  else
-     do j=1,lnum
-        call DclDrawLine( xline(:,j), yline(:,j), index=(90+10*j+1) )
-     end do
+  if(judge=='l'.or.judge=='a')then
+     if(lnum==1)then
+        call DclDrawLine( xline(:,1), yline(:,1) )
+     else
+        nnum=lim/lnum
+        do j=1,lnum
+           call DclDrawLine( xline(:,j), yline(:,j), index=(100+nnum*(j-1)+1) )
+        end do
+     end if
   end if
 
 !  call DclSetContourLabelFormat(form_typec)
@@ -1405,7 +1842,7 @@ end subroutine
 
 !---------------------------------------------------------
 
-subroutine Dcl_PL_calendar( judge, outname, lnum, pnum, lstep, pstep,  &
+subroutine Dcl_PL_calendar( judge, outname,  &
   &  xline, yline, xpoint, ypoint, x_title, y_title, date, days,  &
   &  viewx_min, viewx_max, viewy_min, viewy_max, xmin, xmax, ymin, ymax )
   ! 2 ʿˤʣζ, ݥȤ褹.
@@ -1427,14 +1864,10 @@ subroutine Dcl_PL_calendar( judge, outname, lnum, pnum, lstep, pstep,  &
                 ! 'p' = ݥȤΤ, 'l' = 饤Τ, 'a' = ξ.
                 ! 褷ʤǤ, ߡɤ߹ޤɬפ.
   character(*), intent(in) :: outname  ! դΥȥ
-  integer, intent(in) :: lnum  ! ܿ
-  integer, intent(in) :: pnum  ! ݥȤμ
-  integer, intent(in) :: lstep  !  1 ܤ
-  integer, intent(in) :: pstep  ! 1 ΥݥȤθĿ
-  real, intent(in) :: xline(lstep, lnum)  !  x ɸ
-  real, intent(in) :: yline(lstep, lnum)  !  y ɸ
-  real, intent(in) :: xpoint(pstep, pnum)  ! ݥȷ x ɸ
-  real, intent(in) :: ypoint(pstep, pnum)  ! ݥȷ y ɸ
+  real, intent(in) :: xline(:,:)  !  x ɸ
+  real, intent(in) :: yline(size(xline,1),size(xline,2))  !  y ɸ
+  real, intent(in) :: xpoint(:,:)  ! ݥȷ x ɸ
+  real, intent(in) :: ypoint(size(xpoint,1),size(xpoint,2))  ! ݥȷ y ɸ
   character(*), intent(in) :: x_title  ! x Υȥ
   character(*), intent(in) :: y_title  ! y Υȥ
   type(dcl_date), intent(in) :: date  !  [yyyy:mm:dd]
@@ -1450,8 +1883,14 @@ subroutine Dcl_PL_calendar( judge, outname, lnum, pnum, lstep, pstep,  &
   integer :: i, j, k  ! ź
   integer, parameter :: lim=990  ! 饤󥤥ǥåκ
   integer :: nnum
+  integer :: lstep, pstep, lnum, pnum
   real :: vx_min, vx_max, vy_min, vy_max
 
+  lstep=size(xline,1)
+  pstep=size(xpoint,1)
+  lnum=size(xline,2)
+  pnum=size(xpoint,2)
+
 !-- optional ν ---
   if(present(viewx_min))then
      vx_min=viewx_min
@@ -1586,7 +2025,9 @@ end subroutine
 
 subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max,  &
   &                  vy_min, vy_max, form_types, mono_log, trigle,  &
-  &                  tricmin, tricmax, trifact )  ! ˥ȡСư
+  &                  tricmin, tricmax, trifact )
+!  &                  tricmin, tricmax, trifact, col_mem_num, col_mem_int )
+  ! ˥ȡСư
   use dcl
   implicit none
   integer, intent(in) :: color_num  ! Ѥ뿧ο
@@ -1604,10 +2045,14 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max,  &
   integer, intent(in), optional :: tricmax  ! üѤ顼ޥåֹ 5 
                 ! οꤵƤʤ, color_setting ǥåȤƤ뿧Ȥ褦ˤ.
   real, intent(in), optional :: trifact  ! ѷι⤵ (դƱĹ 1 ȤƤ factor ܤΨ. ǥեȤ 1.)
-  real :: RMISS
+!!!!!!!!!!!!!!!!!!!!!!!!!!!! ʲĤϲ
+!  integer, intent(in), optional :: col_mem_num  ! Сο. ǥե 10.
+!  real, intent(in), optional :: col_mem_int(col_mem_num)  ! ͤꤹ.  col_mem_num ˰.
+  real, parameter :: RMISS=999.0
   integer :: k
   real :: pi(2,color_num+1)
   real :: dp
+!  real, allocatable :: coldim1(:), coldim2(:)
   real :: coldim1(color_num+1), coldim2(color_num/2+1)
   logical :: monoto  ! Υȡν
   real, dimension(3) :: triux, triuy, tridx, tridy
@@ -1615,9 +2060,8 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max,  &
   integer :: tricmin_num, tricmax_num
           ! ¿ѷΰλǤ, ѷĺֺɸ狼Ф褤Τ,
           ! ƺɸ 3 ɬ
-
-!-- Dcl ¦ undef ͥå
-   CALL GLRGET( 'RMISS', RMISS )
+  real :: vpx_min, vpx_max, vpy_min, vpy_max  ! ºݤˤȤ viewport, trigle ѥХåե.
+  integer :: memori_num
 
 !-- ץν
   if(present(mono_log))then
@@ -1652,13 +2096,15 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max,  &
         triux(1)=vx_min
         triux(2)=(vx_max+vx_min)*0.5
         triux(3)=vx_max
-        triuy(1)=vy_max
-        triuy(2)=vy_max+factoru*(vx_max-vx_min)
+        triuy(1)=vy_max-factoru*(vx_max-vx_min)
+        triuy(2)=vy_max
         triuy(3)=triuy(1)
         tridx=triux
-        tridy(1)=vy_min
-        tridy(2)=vy_min-factoru*(vx_max-vx_min)
+        tridy(1)=vy_min+factoru*(vx_max-vx_min)
+        tridy(2)=vy_min
         tridy(3)=tridy(1)
+        vpy_min=tridy(1)
+        vpy_max=triuy(1)
      case('u')
         triux(1)=vx_min
         triux(2)=(vx_max+vx_min)*0.5
@@ -1666,6 +2112,8 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max,  &
         triuy(1)=vy_max
         triuy(2)=vy_max+factoru*(vx_max-vx_min)
         triuy(3)=triuy(1)
+        vpy_min=vy_min
+        vpy_max=triuy(1)
      case('d')
         tridx(1)=vx_min
         tridx(2)=(vx_max+vx_min)*0.5
@@ -1673,14 +2121,27 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max,  &
         tridy(1)=vy_min
         tridy(2)=vy_min-factoru*(vx_max-vx_min)
         tridy(3)=tridy(1)
+        vpy_min=tridy(1)
+        vpy_max=vy_max
      end select
+
+     vpx_min=vx_min
+     vpx_max=vx_max
+
+  else
+
+     vpx_min=vx_min
+     vpx_max=vx_max
+     vpy_min=vy_min
+     vpy_max=vy_max
+
   end if
 
 !-- ޤ
 
   call GRFIG
   call DclSetWindow( 0.0, 1.0, shade_min, shade_max )
-  call DclSetViewPort( vx_min, vx_max, vy_min, vy_max )
+  call DclSetViewPort( vpx_min, vpx_max, vpy_min, vpy_max )
   call GRSTRN(1)
   call DclSetTransFunction
 
@@ -1692,18 +2153,46 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max,  &
   end do
 
 !-- ȡĴ.
+!-- ǥեȤ 10 
+!--  if ʸϤ褯ƹ
 
-  do k=1,color_num+1
-     coldim1(k)=PI(1,k)
-  end do
-  do k=1,color_num/2+1
-     coldim2(k)=PI(1,2*k-1)
-  end do
+ ! if(present(col_mem_num))then
+ !    if(present(col_mem_int))then
+ !       allocate(coldim1(col_mem_num))
+ !       allocate(coldim2(col_mem_num/2))
+ !       do k=1,col_mem_num
+ !          coldim1(k)=col_mem_num(k)
+ !       end do
+ !       do k=1,col_mem_num/2
+ !          coldim1(k)=col_mem_num(2*k-1)
+ !       end do
+ !       do k=1,col_mem_num+1
+ !          coldim1(k)=PI(1,k)
+ !       end do
+ !       do k=1,col_mem_num/2+1
+ !          coldim2(k)=PI(1,2*k-1)
+ !       end do
+ !    else
+ !       do k=1,col_mem_num+1
+ !          coldim1(k)=PI(1,k)
+ !       end do
+ !       do k=1,col_mem_num/2+1
+ !          coldim2(k)=PI(1,2*k-1)
+ !       end do
+ !    end if
+ ! else
+     do k=1,color_num+1
+        coldim1(k)=PI(1,k)
+     end do
+     do k=1,color_num/2+1
+        coldim2(k)=PI(1,2*k-1)
+     end do
+ ! end if
 
   call DclSetXGrid( (/0.0,1.0/) )
   call DclSetYGrid( PI(1,:) )
 
-  if(monoto==.true.)then
+  if(monoto.eqv..true.)then
      call DclSetParm('ENABLE_SOFTFILL',.true.)
      call DclShadeContour( PI )
   else
@@ -1718,7 +2207,7 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max,  &
   CALL UYAXNM( 'R', coldim1, color_num+1, coldim2, color_num/2+1 )
   CALL UYAXNM( 'L', coldim1, color_num+1, coldim2, color_num/2+1 )
 
-!-- ºݤ˻ѷΰ + ѷα
+!-- ºݤ˻ѷΰ
   if(present(trigle))then
      select case(trigle)
      case('a')
@@ -1735,6 +2224,9 @@ subroutine tone_bar( color_num, shade_min, shade_max, vx_min, vx_max,  &
      end select
   end if
 
+!  deallocate(coldim1)
+!  deallocate(coldim2)
+
 !  CALL UYAXDV( 'R', (shade_max-shade_min)/real(color_num), (shade_max-shade_min)/real(0.5*color_num) )
 !  CALL UYAXDV( 'L', (shade_max-shade_min)/real(color_num), (shade_max-shade_min)/real(0.5*color_num) )
 
@@ -1863,7 +2355,7 @@ subroutine color_setting( color_num, val_min, val_max, col_tab,   &
 
   dv=(val_max-val_min)/color_num
 
-  if(rev==.true.)then
+  if(rev.eqv..true.)then
      do k=1,color_num
         TLEV1=val_min+(k-1)*dv
         TLEV2=TLEV1+dv
@@ -1917,7 +2409,7 @@ subroutine monotone_setting( ton_tab, val_min, val_max, nega_ton_tab,  &
 
   if(present(nega_ton_tab))then
      if(present(full_tone))then
-        if(full_tone==.true.)then
+        if(full_tone.eqv..true.)then
            itvtone=12
         else
            itvtone=10
@@ -1927,7 +2419,7 @@ subroutine monotone_setting( ton_tab, val_min, val_max, nega_ton_tab,  &
      end if
   else
      if(present(full_tone))then
-        if(full_tone==.true.)then
+        if(full_tone.eqv..true.)then
            itvtone=6
         else
            itvtone=5
@@ -1972,6 +2464,7 @@ write(*,*) "bgtlev", tlev1, tlev2
 
 end subroutine
 
+!---------------------------------------------------
 !---------------------------------------------------
 
 subroutine undef_get( undef )  ! CReSS ΥǥեȤ̤ͤ롼
@@ -1982,6 +2475,43 @@ subroutine undef_get( undef )  ! CReSS ΥǥեȤ̤ͤ롼
 
 end subroutine
 
+!---------------------------------------------------
+!---------------------------------------------------
+
+subroutine calc_vscale( x_length, y_length, vx_length, vy_length, vx_scale, vy_scale )
+  ! ®٥ȥ襢ڥ˹碌뤿 V ɸϤˤñ̥٥ȥ
+  ! ׻롼. x ͤꤷ, ΤȤ y Υ.
+  ! ׻ˡϰʲΤȤ.
+  ! U ɸϤ (uu, uv) Υ٥ȥ V ɸϤ (vu,vv) ˤ.
+  ! (vu, vv)=(vx_scale*uu, vy_scale*uv) Ȥط.
+  ! , դΰ U, V ɸϤǤ줾 ux, uy, vx, vy Ȥ,
+  ! x  y ο̤Ȥ,
+  ! v ɸϤǤ, vy/vx=v_asp ܤ y ٥ȥˤ,
+  ! u ɸϤǤ, 1/(uy/ux)=1/u_asp ܤ y ٥ȥˤΤ,
+  ! (vu, vv)=(vx_scale*uu, (v_asp/u_asp)*vy_scale*vy) ȤطƤФ褤.
+  ! ˤĤƤξܤǰޤ Tex ե뻲.
+  ! ä, vx_scale, vy_scale ƱΨѲȤ,
+  ! (Ĥޤ, ®٥ȥȤѲȤ)
+  ! vy_scale=vx_scale*v_asp*u_asp Ȥʤ.
+  implicit none
+  real, intent(in) :: x_length  ! Υ [m]
+  real, intent(in) :: y_length  ! Υ [m]
+  real, intent(in) :: vx_length  !  V ϤǤϰ
+  real, intent(in) :: vy_length  !  V ϤǤϰ
+  real, intent(in) :: vx_scale  ! x Υ󥰥ե
+  real, intent(inout) :: vy_scale  ! y Υ󥰥ե
+  real :: u_asp, v_asp
+
+  u_asp=y_length/x_length
+  v_asp=vy_length/vx_length
+
+  vy_scale=(v_asp/u_asp)*vx_scale
+
+end subroutine
+
+!---------------------------------------------------
+!---------------------------------------------------
+
 
 subroutine format_make( val_type, order_num, form_name, frac_num )  ! ͥ٥ѥեޥåȺ롼
   implicit none
@@ -2007,4 +2537,5 @@ subroutine format_make( val_type, order_num, form_name, frac_num )  ! ͥ٥ѥեޥ
 
 end subroutine format_make
 
+
 end module
